@@ -64,7 +64,7 @@ class ApiWrapper:
         self.gateway_handler.create_method_response(resource_id, method, '502', response_parameters)
         self.gateway_handler.create_integration_response(resource_id, method, '502', response_parameters, '\s*.+\s*', get_error_catchall_response_template())
 
-        if 'cors' in configs and configs['cors']:
+        if 'cors' in configs:
             print('Adding CORS to resource')
 
             # if OPTIONS already exists, delete it to be able to replace everything
